/* switch.h
   A switch which can be triggered by user to accomplish something

   Copyright (C) 2000  Mathias Broxvall

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef SWITCH_H
#define SWITCH_H

#include "animated.h"

class CSwitch : public Animated {
 public:
  CSwitch(Game& g, Real x, Real y, SCM on, SCM off);
  virtual ~CSwitch();
  virtual void releaseCallbacks();

  virtual void updateBuffers(const GLuint*, const GLuint*, const GLuint*, bool);
  virtual void drawBuffers1(const GLuint*) const;
  virtual void drawBuffers2(const GLuint*) const;

  virtual void tick(Real);

 private:
  bool is_touched;
  SCM on, off;

  bool bufferIsOn;
  Color bufferPrimaryColor;
  Color bufferSecondaryColor;
};

#endif
